@@ -216,7 +216,7 @@ for(i in 1:length(formsegy) )
            
            fchar=readChar(zz, charlen[i], useBytes = FALSE)
              HEAD[[i]] = fchar
-             print(HEAD[[i]])
+             ## print(HEAD[[i]])
          }
        else
            {
